@@ -7,15 +7,12 @@ use 5.0100;
 use Moose;
 with qw(Business::UPS::Tracking::Role::Print
     Business::UPS::Tracking::Role::Builder);
-__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
 
 no if $] >= 5.017004, warnings => qw(experimental::smartmatch);
 
 use Business::UPS::Tracking::Utils;
 use Business::UPS::Tracking::Element::Activity;
 
-our $VERSION = $Business::UPS::Tracking::VERSION;
-
 =encoding utf8
 
 =head1 NAME
