@@ -7,12 +7,9 @@ use 5.0100;
 use Moose;
 with qw(Business::UPS::Tracking::Role::Print
     Business::UPS::Tracking::Role::Builder);
-__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
 
 use Business::UPS::Tracking::Utils;
 
-our $VERSION = $Business::UPS::Tracking::VERSION;
-
 =encoding utf8
 
 =head1 NAME
