@@ -6,12 +6,9 @@ use 5.0100;
 
 use Moose;
 extends 'Business::UPS::Tracking::Shipment';
-__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
 
 use Business::UPS::Tracking::Element::Package;
 
-our $VERSION = $Business::UPS::Tracking::VERSION;
-
 =encoding utf8
 
 =head1 NAME
